@@ -33,6 +33,8 @@
 flag_options_xref WindowBoxFlagsXref[] = {
     { ASA_Virtual			, WINDOWBOX_Virtual_ID, 0},
     { ASA_VerticalPriority	, WINDOWBOX_VerticalPriority_ID, 0},
+    { ASA_ReverseOrderH		, WINDOWBOX_ReverseOrderHorizontal_ID, 0},
+    { ASA_ReverseOrderV		, WINDOWBOX_ReverseOrderVertical_ID, 0},
     { ASA_ReverseOrder		, WINDOWBOX_ReverseOrder_ID, 0},
     {0, 0, 0}
 };
@@ -44,7 +46,6 @@ flag_options_xref WindowBoxFlagsXref[] = {
  * file
  *
  ****************************************************************************/
-extern SyntaxDef     PopupFuncSyntax ;
 void input_context_destroy(ASHashableValue value, void *data);
 
 flag_options_xref FeelFlagsXref[] = {
@@ -179,6 +180,14 @@ ProcessWindowBoxOptions (FreeStorageElem * options)
                     aswbox->max_layer = item.data.integer ;
                     set_flags( aswbox->set_flags, ASA_MaxLayerSet);
                     break ;
+                case WINDOWBOX_XSpacing_ID        :
+                    aswbox->x_spacing = item.data.integer ;
+                    set_flags( aswbox->set_flags, ASA_XSpacingSet);
+                    break ;
+                case WINDOWBOX_YSpacing_ID        :
+                    aswbox->y_spacing = item.data.integer ;
+                    set_flags( aswbox->set_flags, ASA_YSpacingSet);
+                    break ;
                 default:
 					item.ok_to_free = 1;
                     show_warning( "Unexpected WindowBox definition keyword \"%s\" . Ignoring.", options->term->keyword );
@@ -191,17 +200,16 @@ ProcessWindowBoxOptions (FreeStorageElem * options)
 }
 
 void
-windowbox_parse (char *tline, FILE * fd, char **list, int *count)
+windowbox_parse (char *tline, FILE * fd, char **unused1, int *unused2)
 {
     FilePtrAndData fpd ;
     ConfigDef    *ConfigReader ;
     FreeStorageElem *Storage = NULL, *more_stuff = NULL;
-    ASWindowBox **aswbox_list = (ASWindowBox**)list ;
+    ASWindowBox **aswbox_list = &(ASDefaultScr->Feel.window_boxes);
+	unsigned int *count = &(ASDefaultScr->Feel.window_boxes_num);
     ASWindowBox *new_box ;
 	ConfigData cd ;
 
-    if( list == NULL || count == NULL )
-        return;
     fpd.fp = fd ;
     fpd.data = safemalloc( 12+1+strlen(tline)+1+1 ) ;
     sprintf( fpd.data, "WindowBox %s\n", tline );
@@ -241,8 +249,7 @@ windowbox_parse (char *tline, FILE * fd, char **list, int *count)
 FeelConfig *
 CreateFeelConfig ()
 {
-  FeelConfig *config = (FeelConfig *) safemalloc (sizeof (FeelConfig));
-  memset( config, 0x00, sizeof( FeelConfig ) );
+  FeelConfig *config = (FeelConfig *) safecalloc (1, sizeof (FeelConfig));
   config->more_stuff = NULL;
 
   config->feel = create_asfeel();
@@ -325,7 +332,7 @@ ParseKeyBinding( ConfigItem *item, FreeStorageElem *func_elem, struct FuncKey **
     { /* gotta add it to the keyboard hash */
 		FuncKey *tmp ;
 
-		tmp = (FuncKey *) safemalloc (sizeof (FuncKey));
+		tmp = (FuncKey *) safecalloc (1, sizeof (FuncKey));
 
         tmp->next = *keyboard;
 		*keyboard = tmp ;
@@ -354,7 +361,7 @@ Keyboard2FreeStorage( SyntaxDef *syntax, FreeStorageElem **tail, struct FuncKey
         d_tail = tail ;
         tail = Binding2FreeStorage (syntax, tail, ic->name, ic->cont, ic->mods, id);
         if( tail != d_tail && *d_tail )   /* saving our function as a sub-elem */
-            Func2FreeStorage( &FuncSyntax, &((*d_tail)->sub), ic->fdata );
+            Func2FreeStorage( pFuncSyntax, &((*d_tail)->sub), ic->fdata );
 		ic = ic->next ;
     }
     return tail;
@@ -375,7 +382,7 @@ Mouse2FreeStorage( SyntaxDef *syntax, FreeStorageElem **tail, struct MouseButton
 		sprintf( &(buffer[0]), "%d", ic->Button );
         tail = Binding2FreeStorage (syntax, tail, buffer, ic->Context, ic->Modifier, id);
         if( tail != d_tail && *d_tail )   /* saving our function as a sub-elem */
-            Func2FreeStorage( &FuncSyntax, &((*d_tail)->sub), ic->fdata );
+            Func2FreeStorage( pFuncSyntax, &((*d_tail)->sub), ic->fdata );
 		ic = ic->NextButton ;
     }
     return tail;
