@@ -147,6 +147,10 @@ PrintMyStyleDefinitions (MyStyleDefinition * list)
 		if (list->back_color)
 			fprintf (stderr, "\n\tBackColor %s", list->back_color);
 		fprintf (stderr, "\n\tTextStyle %d", list->text_style);
+		fprintf (stderr, "\n\tSliceXStart %d", list->slice_x_start);
+		fprintf (stderr, "\n\tSliceXEnd %d", list->slice_x_end);
+		fprintf (stderr, "\n\tSliceYStart %d", list->slice_y_start);
+		fprintf (stderr, "\n\tSliceYEnd %d", list->slice_y_end);
 		if( get_flags( list->flags, MYSTYLE_DRAW_TEXT_BACKGROUND ) )
 			fprintf (stderr, "\n\tDrawTextBackground");
 		if( list->texture_type > 0 )
@@ -241,18 +245,34 @@ ProcessMyStyleOptions (FreeStorageElem * options, MyStyleDefinition ** tail)
 			}
 			break;
 		 case MYSTYLE_FONT_ID:
-			set_string_value( &((*tail)->font), item.data.string, NULL, 0);
+			set_string( &((*tail)->font), item.data.string);
 			break;
 		 case MYSTYLE_FORECOLOR_ID:
-			set_string_value( &((*tail)->fore_color), item.data.string, NULL, 0);
+			set_string( &((*tail)->fore_color), item.data.string);
 			break;
 		 case MYSTYLE_BACKCOLOR_ID:
-			set_string_value( &((*tail)->back_color), item.data.string, NULL, 0);
+			set_string( &((*tail)->back_color), item.data.string);
 			break;
 		 case MYSTYLE_TEXTSTYLE_ID:
 			(*tail)->text_style = item.data.integer;
 			set_flags( (*tail)->flags, MYSTYLE_TEXT_STYLE_SET );
 			break;
+		 case MYSTYLE_SliceXStart_ID:
+			(*tail)->slice_x_start = item.data.integer;
+			set_flags( (*tail)->flags, MYSTYLE_SLICE_SET );
+			break;
+		 case MYSTYLE_SliceXEnd_ID:
+			(*tail)->slice_x_end = item.data.integer;
+			set_flags( (*tail)->flags, MYSTYLE_SLICE_SET );
+			break;
+		 case MYSTYLE_SliceYStart_ID:
+			(*tail)->slice_y_start = item.data.integer;
+			set_flags( (*tail)->flags, MYSTYLE_SLICE_SET );
+			break;
+		 case MYSTYLE_SliceYEnd_ID:
+			(*tail)->slice_y_end = item.data.integer;
+			set_flags( (*tail)->flags, MYSTYLE_SLICE_SET );
+			break;
 		 case MYSTYLE_BACKGRADIENT_ID:
 			if( options->argc != 3 )
 				show_error( "invalid number of colors in BackGradient definition (%d)", options->argc );
@@ -299,7 +319,7 @@ ProcessMyStyleOptions (FreeStorageElem * options, MyStyleDefinition ** tail)
 		 	{
 				MyStyleDefinition *msd = *tail ;
 				if (options->argc > 1)
-					set_string_value( &(msd->back_pixmap), mystrdup (options->argv[1]), NULL, 0 );
+					set_string( &(msd->back_pixmap), mystrdup (options->argv[1]) );
 				else
 				{
 					free(msd->back_pixmap);
@@ -399,6 +419,14 @@ mystyle_create_from_definition (MyStyleDefinition * def)
 		set_flags( style->user_flags, F_TEXTSTYLE );
 		style->text_style = def->text_style;
 	}
+	if( get_flags(def->flags, MYSTYLE_SLICE_SET ) )
+	{
+		set_flags( style->user_flags, F_SLICE );
+		style->slice_x_start = def->slice_x_start;
+		style->slice_x_end = def->slice_x_end;
+		style->slice_y_start = def->slice_y_start;
+		style->slice_y_end = def->slice_y_end;
+	}
 	if( def->fore_color )
 	{
 		if (parse_argb_color (def->fore_color, &(style->colors.fore)) != def->fore_color)
@@ -499,7 +527,7 @@ mystyle_create_from_definition (MyStyleDefinition * def)
 			style->texture_type = type;
 		} else
         {  /* treat second parameter as an image filename : */
-        	if ( load_icon(&(style->back_icon), def->back_pixmap, Scr.image_manager ))
+        	if ( load_icon(&(style->back_icon), def->back_pixmap, get_screen_image_manager(NULL) ))
 			{
 				set_flags (style->user_flags, F_BACKPIXMAP);
 				if (type >= TEXTURE_TRANSPIXMAP)
@@ -587,11 +615,11 @@ MergeMyStyleText (MyStyleDefinition ** list, const char *name,
 	if ((style = GetMyStyleDefinition (list, name, True)) != NULL)
 	{
 		if (new_font)
-			set_string_value( &(style->font), mystrdup (new_font), NULL, 0 );
+			set_string( &(style->font), mystrdup (new_font) );
 		if (new_fcolor)
-			set_string_value( &(style->fore_color), mystrdup (new_fcolor), NULL, 0 );
+			set_string( &(style->fore_color), mystrdup (new_fcolor) );
 		if (new_bcolor)
-			set_string_value( &(style->back_color), mystrdup (new_bcolor), NULL, 0 );
+			set_string( &(style->back_color), mystrdup (new_bcolor) );
 		if (new_style >= 0)
 		{
 			style->text_style = new_style;
