@@ -56,6 +56,7 @@ ASDocTagHandlingInfo SupportedDocBookTagInfo[DOCBOOK_SUPPORTED_IDS] =
 	{ TAG_INFO_AND_ID(section), start_section_tag, end_section_tag },
 	{ TAG_INFO_AND_ID(fileref), NULL, NULL },
 	{ TAG_INFO_AND_ID(refsect1), start_refsect1_tag, end_refsect1_tag },
+	{ TAG_INFO_AND_ID(refsect2), start_refsect1_tag, end_refsect1_tag },
 	{ TAG_INFO_AND_ID(emphasis), start_emphasis_tag, end_emphasis_tag },
 	{ TAG_INFO_AND_ID(listitem), start_listitem_tag, end_listitem_tag },
 	{ TAG_INFO_AND_ID(imagedata), start_imagedata_tag, end_imagedata_tag },
@@ -134,8 +135,8 @@ write_doc_cdata( const char *cdata, int len, ASXMLInterpreterState *state )
 				token_start = i+1 ;
 				
 				if( cdata[i] == '&' )
-					special = ( translate_special_sequence( &(cdata[i]), len-i,  NULL ) == '\0' );
-				if( cdata[i] == ';' && special ) 		   
+					special = ( translate_special_sequence( &(cdata[i]), len-i,  NULL ) != '\0' );
+				else if( cdata[i] == ';' && special ) 		   
 					special = False ;
 				switch( cdata[i] )
 				{
@@ -160,8 +161,10 @@ write_doc_cdata( const char *cdata, int len, ASXMLInterpreterState *state )
 		for( i = 0 ; i < len ; ++i ) 
 		{
 			int c_len = 0 ;
-			int c = translate_special_sequence( &(cdata[i]), len-i, &c_len ) ;
+			int c = '\0' ; 
 			
+			if( cdata[i] == '&' ) 
+				c = translate_special_sequence( &(cdata[i]), len-i, &c_len ) ;
 			if( c != '\0' )
 				i += c_len-1 ;	
 			else
@@ -212,7 +215,7 @@ convert_xml_tag( xml_elem_t *doc, xml_elem_t **rparm, ASXMLInterpreterState *sta
 	}	 
 	for (ptr = doc->child ; ptr ; ptr = ptr->next) 
 	{
-		LOCAL_DEBUG_OUT( "handling tag's data \"%s\"", ptr->parm );
+		/* LOCAL_DEBUG_OUT( "handling tag's data \"%s\"", ptr->parm ); */
 		if (ptr->tag_id == XML_CDATA_ID ) 
 		{
 			const char *data_ptr = ptr->parm ;
@@ -260,13 +263,13 @@ convert_xml_tag( xml_elem_t *doc, xml_elem_t **rparm, ASXMLInterpreterState *sta
 		}else 
 			convert_xml_tag( ptr, NULL, state );
 	}
-	LOCAL_DEBUG_OUT( "handling end tag with func %p", SupportedDocBookTagInfo[doc->tag_id].handle_end_tag );
+	/* LOCAL_DEBUG_OUT( "handling end tag with func %p", SupportedDocBookTagInfo[doc->tag_id].handle_end_tag ); */
 	if( state->doc_type != DocType_XML ) 
 	{
 		if( doc->tag_id > 0 && doc->tag_id < DOCBOOK_SUPPORTED_IDS ) 
 			if( SupportedDocBookTagInfo[doc->tag_id].handle_end_tag ) 
 				SupportedDocBookTagInfo[doc->tag_id].handle_end_tag( doc, parm, state ); 
-		LOCAL_DEBUG_OUT( "xml_elem_delete for parm %p", parm );
+/*		LOCAL_DEBUG_OUT( "xml_elem_delete for parm %p", parm ); */
 		if (rparm) *rparm = parm; 
 		else xml_elem_delete(NULL, parm);
 	}else
@@ -285,7 +288,8 @@ convert_xml_file( const char *syntax_dir, const char *file, ASXMLInterpreterStat
 	
 	source_file = make_file_name( syntax_dir, file );
 	doc_str = load_file(source_file);
-	LOCAL_DEBUG_OUT( "file %s loaded into {%s}", source_file, doc_str );
+	LOCAL_DEBUG_OUT( "file %s loaded", source_file );
+	/*LOCAL_DEBUG_OUT( "file %s loaded into {%s}", source_file, doc_str ); */
 	if( doc_str != NULL )
 	{
 		xml_elem_t* doc;
@@ -376,7 +380,14 @@ close_link( ASXMLInterpreterState *state )
 			fwrite( "</A>", 1, 4, state->dest_fp );	   
 		}else if( state->doc_type == DocType_PHP )
 		{
-			fprintf( state->dest_fp, "\",\"%s\",$srcunset,$subunset) ?>", state->curr_url_page);	   
+			if ( TopicIndexName == NULL )
+			{
+			    fprintf( state->dest_fp, "\",\"%s\",\"%s\",$subunset) ?>", state->curr_url_page, state->display_name);
+			}
+			else
+			{
+			    fprintf( state->dest_fp, "\",\"%s\",$srcunset,$subunset) ?>", state->curr_url_page);
+			}
 			 							
 		}	 
 		clear_flags( state->flags, ASXMLI_InsideLink|ASXMLI_LinkIsLocal|ASXMLI_LinkIsURL );
@@ -437,7 +448,9 @@ add_local_link( xml_elem_t *attr, ASXMLInterpreterState *state )
 			if( state->curr_url_page[l-1] != '/' && 
 				( l < 5 || mystrcasecmp( &(state->curr_url_page[l-5]), ".html" ) != 0) && 
 				( l < 4 || mystrcasecmp( &(state->curr_url_page[l-4]), ".php" ) != 0) &&
-				( l < 4 || mystrcasecmp( &(state->curr_url_page[l-4]), ".htm" ) != 0) )
+				( l < 4 || mystrcasecmp( &(state->curr_url_page[l-4]), ".htm" ) != 0) &&
+				( l < 4 || mystrcasecmp( &(state->curr_url_page[l-4]), ".jpg" ) != 0) &&
+				( l < 4 || mystrcasecmp( &(state->curr_url_page[l-4]), ".png" ) != 0))
 			{
 				set_flags( state->flags, ASXMLI_LinkIsLocal );
 			}
@@ -453,6 +466,11 @@ add_local_link( xml_elem_t *attr, ASXMLInterpreterState *state )
 				fwrite( "\">", 1, 2, state->dest_fp );
 			}else if( state->doc_type == DocType_PHP ) 
 			{
+			    if (TopicIndexName == NULL) /* added for php part of data catalogue */
+			    {
+				fprintf( state->dest_fp, "<? local_doc_url(\"graphics.php\",\"" );
+			    }
+			    else
 				fprintf( state->dest_fp, "<? local_doc_url(\"visualdoc.php\",\"" );
 			}
 			set_flags( state->flags, ASXMLI_InsideLink|ASXMLI_LinkIsURL  );
@@ -635,8 +653,8 @@ start_varlistentry_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState
 {
 	if( state->doc_type == DocType_HTML	|| state->doc_type == DocType_PHP	 )
 		add_anchor( parm, state );
-	else if( state->doc_type == DocType_NROFF )
-		fprintf( state->dest_fp, "\n.IP ");
+ /*	else if( state->doc_type == DocType_NROFF )
+		fprintf( state->dest_fp, "\n.IP "); */
 
 }
 
@@ -666,6 +684,7 @@ start_term_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *state
 		fprintf( state->dest_fp, "<DT class=\"dense\"><B>" );	
 	else if( state->doc_type == DocType_NROFF )
 	{	
+		fprintf( state->dest_fp, "\n.IP ");
 		fprintf( state->dest_fp, "\"");
 		set_flags( state->flags, ASXMLI_EscapeDQuotes);
 	}
@@ -675,7 +694,7 @@ void
 end_term_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *state )
 {
 	if( state->doc_type == DocType_HTML || state->doc_type == DocType_PHP	 )
-		fwrite( "</B></DT>", 1, 9, state->dest_fp );	
+		fwrite( "</B></DT>", 1, 9, state->dest_fp );
 	else if( state->doc_type == DocType_NROFF )
 	{	
 		fprintf( state->dest_fp, "\"\n");
@@ -720,8 +739,10 @@ start_imagedata_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *s
 			}	 
 			parm = parm->next ;
 		}		
-
-		fprintf( state->dest_fp, "<IMG src=\"%s\"", url );	
+		if (  state->doc_type == DocType_PHP ) 
+		    fprintf( state->dest_fp, "<IMG SRC=%s/%s", state->dest_dir, url );
+		else
+		    fprintf( state->dest_fp, "<IMG src=\"%s\"", url );
 		if( align != NULL ) 
 			fprintf( state->dest_fp, " align=\"%s\"", align );	 
 		if( valign != NULL ) 
@@ -738,8 +759,10 @@ void
 end_imagedata_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *state )
 {
 	close_link(state);
-	if( state->doc_type == DocType_HTML || state->doc_type == DocType_PHP	  	)
-		fwrite( "</IMG>", 1, 6, state->dest_fp );	
+	if( state->doc_type == DocType_HTML || state->doc_type == DocType_PHP	)
+		fwrite( "</IMG>", 1, 6, state->dest_fp );
+//		fprintf( state->dest_fp, "\n", NULL );
+		fputc( '\n', state->dest_fp );
 }
 
 
@@ -753,7 +776,10 @@ start_section_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *sta
 			fwrite( "<HR>\n", 1, 5, state->dest_fp );
 		 */
 		add_anchor( parm, state );
-		fwrite( "<UL>", 1, 4, state->dest_fp );
+		if( get_flags( state->flags, ASXMLI_OrderSections ) )
+			fwrite( "<OL>", 1, 4, state->dest_fp );
+		else
+			fwrite( "<UL>", 1, 4, state->dest_fp );
 	}
 }
 
@@ -763,7 +789,10 @@ end_section_tag( xml_elem_t *doc, xml_elem_t *parm, ASXMLInterpreterState *state
 	--(state->header_depth);	
 	if( state->doc_type == DocType_HTML	|| state->doc_type == DocType_PHP	 )
 	{
-		fwrite( "</UL>", 1, 5, state->dest_fp );
+		if( get_flags( state->flags, ASXMLI_OrderSections ) )
+			fwrite( "</OL>", 1, 5, state->dest_fp );
+		else
+			fwrite( "</UL>", 1, 5, state->dest_fp );
 	}
 }
 
